==> cognitoapigatewaylambda-1.157.0-sources.jar: software/amazon/awsconstructs/services/cognitoapigatewaylambda/CognitoToApiGatewayToLambda.java <==
package software.amazon.awsconstructs.services.cognitoapigatewaylambda;

@javax.annotation.Generated(value = "jsii-pacmak/1.60.1 (build 2799dc8)", date = "2022-06-13T19:45:22.427Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cognitoapigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-cognito-apigateway-lambda.CognitoToApiGatewayToLambda")
public class CognitoToApiGatewayToLambda extends software.amazon.awscdk.core.Construct {

    protected CognitoToApiGatewayToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CognitoToApiGatewayToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public CognitoToApiGatewayToLambda(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public void addAuthorizers() {
        software.amazon.jsii.Kernel.call(this, "addAuthorizers", software.amazon.jsii.NativeType.VOID);
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.RestApi getApiGateway() {
        return software.amazon.jsii.Kernel.get(this, "apiGateway", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.RestApi.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.CfnAuthorizer getApiGatewayAuthorizer() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayAuthorizer", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.CfnAuthorizer.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.LogGroup getApiGatewayLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPool getUserPool() {
        return software.amazon.jsii.Kernel.get(this, "userPool", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPool.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolClient getUserPoolClient() {
        return software.amazon.jsii.Kernel.get(this, "userPoolClient", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPoolClient.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.Role getApiGatewayCloudWatchRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayCloudWatchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambdaProps.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambdaProps.Builder();
        }

        /**
         * Optional user provided props to override the default props for the API Gateway.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param apiGatewayProps Optional user provided props to override the default props for the API Gateway. This parameter is required.
         */
        public Builder apiGatewayProps(final java.lang.Object apiGatewayProps) {
            this.props.apiGatewayProps(apiGatewayProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cognitoUserPoolClientProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder cognitoUserPoolClientProps(final java.lang.Object cognitoUserPoolClientProps) {
            this.props.cognitoUserPoolClientProps(cognitoUserPoolClientProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cognitoUserPoolProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder cognitoUserPoolProps(final software.amazon.awscdk.services.cognito.UserPoolProps cognitoUserPoolProps) {
            this.props.cognitoUserPoolProps(cognitoUserPoolProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda build() {
            return new software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> cognitoapigatewaylambda-2.12.0-sources.jar: software/amazon/awsconstructs/services/cognitoapigatewaylambda/CognitoToApiGatewayToLambda.java <==
package software.amazon.awsconstructs.services.cognitoapigatewaylambda;

@javax.annotation.Generated(value = "jsii-pacmak/1.62.0 (build 293ac17)", date = "2022-07-26T15:51:51.582Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.cognitoapigatewaylambda.$Module.class, fqn = "@aws-solutions-constructs/aws-cognito-apigateway-lambda.CognitoToApiGatewayToLambda")
public class CognitoToApiGatewayToLambda extends software.constructs.Construct {

    protected CognitoToApiGatewayToLambda(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CognitoToApiGatewayToLambda(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public CognitoToApiGatewayToLambda(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambdaProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public void addAuthorizers() {
        software.amazon.jsii.Kernel.call(this, "addAuthorizers", software.amazon.jsii.NativeType.VOID);
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.RestApi getApiGateway() {
        return software.amazon.jsii.Kernel.get(this, "apiGateway", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.RestApi.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.apigateway.CfnAuthorizer getApiGatewayAuthorizer() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayAuthorizer", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.apigateway.CfnAuthorizer.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.logs.LogGroup getApiGatewayLogGroup() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayLogGroup", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.logs.LogGroup.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPool getUserPool() {
        return software.amazon.jsii.Kernel.get(this, "userPool", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPool.class));
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolClient getUserPoolClient() {
        return software.amazon.jsii.Kernel.get(this, "userPoolClient", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.UserPoolClient.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.iam.Role getApiGatewayCloudWatchRole() {
        return software.amazon.jsii.Kernel.get(this, "apiGatewayCloudWatchRole", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.iam.Role.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambdaProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambdaProps.Builder();
        }

        /**
         * Optional user provided props to override the default props for the API Gateway.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param apiGatewayProps Optional user provided props to override the default props for the API Gateway. This parameter is required.
         */
        public Builder apiGatewayProps(final java.lang.Object apiGatewayProps) {
            this.props.apiGatewayProps(apiGatewayProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cognitoUserPoolClientProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder cognitoUserPoolClientProps(final java.lang.Object cognitoUserPoolClientProps) {
            this.props.cognitoUserPoolClientProps(cognitoUserPoolClientProps);
            return this;
        }

        /**
         * Optional user provided props to override the default props.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param cognitoUserPoolProps Optional user provided props to override the default props. This parameter is required.
         */
        public Builder cognitoUserPoolProps(final software.amazon.awscdk.services.cognito.UserPoolProps cognitoUserPoolProps) {
            this.props.cognitoUserPoolProps(cognitoUserPoolProps);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, providing both this and `lambdaFunctionProps` will cause an error. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * User provided props to override the default props for the CloudWatchLogs LogGroup.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param logGroupProps User provided props to override the default props for the CloudWatchLogs LogGroup. This parameter is required.
         */
        public Builder logGroupProps(final software.amazon.awscdk.services.logs.LogGroupProps logGroupProps) {
            this.props.logGroupProps(logGroupProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda}.
         */
        @Override
        public software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda build() {
            return new software.amazon.awsconstructs.services.cognitoapigatewaylambda.CognitoToApiGatewayToLambda(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
